@@ -12,7 +12,6 @@ import uuid
 from itertools import chain
 
 import attr
-import Levenshtein
 from logzero import logger
 from tabulate import tabulate
 
@@ -28,6 +27,7 @@ from ..api import (
     CaseImportState,
     CaseImportInfo,
     DatabaseInfoFile,
+    VariantSetImportState,
 )
 from .config import CaseCreateImportInfoConfig
 
@@ -292,6 +292,7 @@ class CaseImporter:
             server_url=self.global_config.varfish_server_url,
             api_token=self.global_config.varfish_api_token,
             case_import_info_uuid=case_import_info.sodar_uuid,
+            verify_ssl=self.global_config.verify_ssl,
         )
         for bam_qc_file in bam_qc_files:
             if bam_qc_file.md5 not in good_md5s:
@@ -300,18 +301,21 @@ class CaseImporter:
                     api_token=self.global_config.varfish_api_token,
                     case_import_info_uuid=case_import_info.sodar_uuid,
                     bam_qc_file_uuid=bam_qc_file.sodar_uuid,
+                    verify_ssl=self.global_config.verify_ssl,
                 )
 
         variant_sets = api.variant_set_import_info_list(
             server_url=self.global_config.varfish_server_url,
             api_token=self.global_config.varfish_api_token,
             case_import_info_uuid=case_import_info.sodar_uuid,
+            verify_ssl=self.global_config.verify_ssl,
         )
         for variant_set in variant_sets:
             genotype_files = api.genotype_file_list(
                 server_url=self.global_config.varfish_server_url,
                 api_token=self.global_config.varfish_api_token,
                 variant_set_import_info_uuid=variant_set.sodar_uuid,
+                verify_ssl=self.global_config.verify_ssl,
             )
             for gt_file in genotype_files:
                 if gt_file.md5 not in good_md5s:
@@ -320,11 +324,13 @@ class CaseImporter:
                         api_token=self.global_config.varfish_api_token,
                         variant_set_import_info_uuid=variant_set.sodar_uuid,
                         genotype_file_uuid=gt_file.sodar_uuid,
+                        verify_ssl=self.global_config.verify_ssl,
                     )
             effect_files = api.effects_file_list(
                 server_url=self.global_config.varfish_server_url,
                 api_token=self.global_config.varfish_api_token,
                 variant_set_import_info_uuid=variant_set.sodar_uuid,
+                verify_ssl=self.global_config.verify_ssl,
             )
             for eff_file in effect_files:
                 if eff_file.md5 not in good_md5s:
@@ -333,11 +339,13 @@ class CaseImporter:
                         api_token=self.global_config.varfish_api_token,
                         variant_set_import_info_uuid=variant_set.sodar_uuid,
                         effects_file_uuid=eff_file.sodar_uuid,
+                        verify_ssl=self.global_config.verify_ssl,
                     )
             db_info_files = api.db_info_file_list(
                 server_url=self.global_config.varfish_server_url,
                 api_token=self.global_config.varfish_api_token,
                 variant_set_import_info_uuid=variant_set.sodar_uuid,
+                verify_ssl=self.global_config.verify_ssl,
             )
             for db_info_file in db_info_files:
                 if db_info_file.md5 not in good_md5s:
@@ -346,6 +354,7 @@ class CaseImporter:
                         api_token=self.global_config.varfish_api_token,
                         variant_set_import_info_uuid=variant_set.sodar_uuid,
                         db_info_file_uuid=db_info_file.sodar_uuid,
+                        verify_ssl=self.global_config.verify_ssl,
                     )
 
     def _split_files_by_role(self):
@@ -427,9 +436,18 @@ class CaseImporter:
             server_url=self.global_config.varfish_server_url,
             api_token=self.global_config.varfish_api_token,
             project_uuid=self.create_config.project_uuid,
+            verify_ssl=self.global_config.verify_ssl,
         ):
             if strip_suffix(case_info.name) == name:
-                if self.create_config.resubmit and case_info.state != CaseImportState.DRAFT:
+                logger.info("Found existing case info: %s", case_info)
+                # Make sure to update index and pedigree to current value.
+                case_info = attr.assoc(case_info, index=index, pedigree=self.pedigree)
+                if self.create_config.resubmit and case_info.state in (
+                    CaseImportState.SUBMITTED,
+                    CaseImportState.IMPORTED,
+                    CaseImportState.FAILED,
+                ):
+                    logger.info("Case is submitted and --resubmit given, marking as draft.")
                     case_info = attr.assoc(case_info, state=CaseImportState.DRAFT)
                     logger.info("Updating state existing case draft info: %s", case_info)
                     api.case_import_info_update(
@@ -438,6 +456,7 @@ class CaseImporter:
                         project_uuid=self.create_config.project_uuid,
                         case_import_info_uuid=case_info.sodar_uuid,
                         data=case_info,
+                        verify_ssl=self.global_config.verify_ssl,
                     )
                     return case_info
                 elif (
@@ -451,6 +470,7 @@ class CaseImporter:
                 api_token=self.global_config.varfish_api_token,
                 project_uuid=self.create_config.project_uuid,
                 data=models.CaseImportInfo(name=name, index=index, pedigree=self.pedigree),
+                verify_ssl=self.global_config.verify_ssl,
             )
 
     def _check_genotypes(self):
@@ -458,12 +478,15 @@ class CaseImporter:
         with_gts = {m.name for m in self.pedigree if m.has_gt_entries}
         for path in chain(self.paths_genotype, self.paths_genotype_sv):
             logger.debug("Checking genotype vs. pedigree samples for %s", path.path)
-            gts = self._load_dict_col(path.path, "genotype").keys()
+            dict_col = self._load_dict_col(path.path, "genotype")
+            if not dict_col:
+                print("INFO: empty file %s" % path.path, file=sys.stderr)
+                continue
+            gts = dict_col.keys()
             if gts != with_gts:
-                raise InconsistentSamplesDataException(
-                    "Inconsistent samples in %s vs. %s (exclusive %s vs. %s)"
-                    % (path.path, self.path_ped.path, gts - with_gts, with_gts - gts)
-                )
+                tpl = "Inconsistent samples in %s vs. %s (exclusive %s vs. %s)"
+                args = (path.path, self.path_ped.path, gts - with_gts, with_gts - gts)
+                print("WARNING: %s" % (tpl % args), file=sys.stderr)
 
     def _check_bam_qc(self):
         """Check bam_qc."""
@@ -517,8 +540,8 @@ class CaseImporter:
 
     def _load_dict_col(self, genotype_file, column):
         with gzip.open(genotype_file, "rt") as inputf:
-            first_line = inputf.readline().splitlines(False)[0]
-            second_line = inputf.readline().splitlines(False)[0]
+            first_line = inputf.readline().strip()
+            second_line = inputf.readline().strip()
             if not second_line:
                 return None
             else:
@@ -545,6 +568,7 @@ class CaseImporter:
             server_url=self.global_config.varfish_server_url,
             api_token=self.global_config.varfish_api_token,
             **{func_uuid_arg: uuid_value},
+            verify_ssl=self.global_config.verify_ssl,
         ):
             if file_obj.md5 == md5:
                 logger.debug("- found %s with md5 %s", obj_type, md5)
@@ -558,6 +582,7 @@ class CaseImporter:
                     **{func_uuid_arg: uuid_value},
                     data=file_type(name=os.path.basename(path), md5=md5),
                     files={"file": handle},
+                    verify_ssl=self.global_config.verify_ssl,
                 )
                 return md5
 
@@ -625,6 +650,14 @@ class CaseImporter:
                 )
                 for path in db_infos_small
             ]
+            api.variant_set_import_info_update(
+                server_url=self.global_config.varfish_server_url,
+                api_token=self.global_config.varfish_api_token,
+                case_import_info_uuid=case_import_info.sodar_uuid,
+                variant_set_import_info_uuid=variant_set_import_info.sodar_uuid,
+                data=attr.assoc(variant_set_import_info, state=VariantSetImportState.UPLOADED),
+                verify_ssl=self.global_config.verify_ssl,
+            )
 
         if self.paths_genotype_sv:
             logger.info("- create new structural variant set if necessary")
@@ -667,6 +700,14 @@ class CaseImporter:
                 )
                 for path in db_infos_sv
             ]
+            api.variant_set_import_info_update(
+                server_url=self.global_config.varfish_server_url,
+                api_token=self.global_config.varfish_api_token,
+                case_import_info_uuid=case_import_info.sodar_uuid,
+                variant_set_import_info_uuid=variant_set_import_info.sodar_uuid,
+                data=attr.assoc(variant_set_import_info, state=VariantSetImportState.UPLOADED),
+                verify_ssl=self.global_config.verify_ssl,
+            )
 
         return good_md5s
 
@@ -675,13 +716,37 @@ class CaseImporter:
     ):
         """Create variant set import info necessary."""
 
-        for case_info in api.variant_set_import_info_list(
+        for variant_set_info in api.variant_set_import_info_list(
             server_url=self.global_config.varfish_server_url,
             api_token=self.global_config.varfish_api_token,
             case_import_info_uuid=case_import_info.sodar_uuid,
+            verify_ssl=self.global_config.verify_ssl,
         ):
-            if case_info.variant_type == variant_type:
-                return case_info
+            if not variant_set_info.variant_type == variant_type:
+                continue
+            if self.create_config.resubmit and variant_set_info.state in (
+                VariantSetImportState.UPLOADED,
+                VariantSetImportState.IMPORTED,
+                VariantSetImportState.FAILED,
+            ):
+                logger.info("Variant set is submitted and --resubmit given, marking as draft.")
+                variant_set_info = attr.assoc(variant_set_info, state=VariantSetImportState.DRAFT)
+                logger.info("Updating state existing variant set draft info: %s", variant_set_info)
+                api.variant_set_import_info_update(
+                    server_url=self.global_config.varfish_server_url,
+                    api_token=self.global_config.varfish_api_token,
+                    case_import_info_uuid=case_import_info.sodar_uuid,
+                    variant_set_import_info_uuid=variant_set_info.sodar_uuid,
+                    data=variant_set_info,
+                    verify_ssl=self.global_config.verify_ssl,
+                )
+                return variant_set_info
+            elif (
+                variant_set_info.state == VariantSetImportState.DRAFT
+                and not self.create_config.force_fresh
+            ):
+                logger.info("Found existing variant_set draft info: %s", variant_set_info)
+                return variant_set_info
         else:  # found no match
             return api.variant_set_import_info_create(
                 server_url=self.global_config.varfish_server_url,
@@ -690,6 +755,7 @@ class CaseImporter:
                 data=models.VariantSetImportInfo(
                     genomebuild=GenomeBuild.GRCH37, variant_type=variant_type
                 ),
+                verify_ssl=self.global_config.verify_ssl,
             )
 
     def _submit_import(self, case_import_info: models.CaseImportInfo):
@@ -700,6 +766,7 @@ class CaseImporter:
             project_uuid=self.create_config.project_uuid,
             case_import_info_uuid=case_import_info.sodar_uuid,
             data=attr.assoc(case_import_info, state=CaseImportState.SUBMITTED),
+            verify_ssl=self.global_config.verify_ssl,
         )
 
 
